@@ -1,4 +1,4 @@
-/*	$Id: ModemConfig.h,v 1.9 2002/02/15 03:55:06 darren Exp $ */
+/*	$Id: ModemConfig.h,v 1.16 2002/09/13 16:55:18 darren Exp $ */
 /*
  * Copyright (c) 1990-1996 Sam Leffler
  * Copyright (c) 1991-1996 Silicon Graphics, Inc.
@@ -94,6 +94,7 @@ public:
     fxStr	ringData;		// data call ring string
     fxStr	ringFax;		// fax call ring string
     fxStr	ringVoice;		// voice call ring string
+    fxStr	ringExtended;		// extended ring
 					// caller id
     fxStr	cidName;		// pattern for name info
     fxStr	cidNumber;		// pattern for number info
@@ -112,18 +113,21 @@ public:
     fxStr	class1SFLOCmd;		// cmd to setup software flow control
     fxStr	class1HFLOCmd;		// cmd to setup hardware flow control
     fxStr	class1PPMWaitCmd;	// cmd to stop and wait prior to PPM
+    fxStr	class1ResponseWaitCmd;	// cmd to wait prior to TCF response
     fxStr	class1TCFWaitCmd;	// cmd to stop and wait prior to TCF
     fxStr	class1EOPWaitCmd;	// cmd to stop and wait prior to EOP
+    fxStr	class1SwitchingCmd;	// after recv HDLC and before sending
+    fxStr	class1MsgRecvHackCmd;	// cmd to avoid +FCERROR before image
     u_int	class1TCFRecvTimeout;	// timeout receiving TCF
     u_int	class1TCFResponseDelay;	// delay (ms) btwn TCF & ack/nak
     u_int	class1SendMsgDelay;	// delay (ms) after training
-    u_int	class1SwitchingDelay;	// delay (ms) in switching transmission direction
     u_int	class1TrainingRecovery;	// delay (ms) after failed training
     u_int	class1RecvAbortOK;	// if non-zero, OK sent after recv abort
     u_int	class1FrameOverhead;	// overhead bytes in received frames
     u_int	class1RecvIdentTimer;	// timeout receiving initial identity
     u_int	class1TCFMaxNonZero;	// non-zero threshold for TCF check
     u_int	class1TCFMinRun;	// min length of zero run for TCF check
+    bool	class1TCFRecvHack;	// deliberately look for V.21 disconnect
 					// for class 2 and 2.0:
     fxStr	class2Cmd;		// cmd for setting Class 2/2.0
     fxStr	class2DCCQueryCmd;	// cmd to query modem capabilities
@@ -143,12 +147,14 @@ public:
     fxStr	class2CIGCmd;		// cmd to set polling identifier
     fxStr	class2SPLCmd;		// cmd to set polling request
     fxStr	class2PTSCmd;		// cmd to set page status
+    fxStr	class2PTSQueryCmd;	// cmd to query page status
     fxStr	class2NFLOCmd;		// cmd to setup no flow control
     fxStr	class2SFLOCmd;		// cmd to setup software flow control
     fxStr	class2HFLOCmd;		// cmd to setup hardware flow control
     fxStr	class2MINSPCmd;		// cmd to setup min transmit speed
     fxStr	class2RecvDataTrigger;	// send to start recv
     bool	class2XmitWaitForXON;	// wait for XON before send
+    bool	class2RTFCC;		// real-time fax compression conversion
     bool	class2SendRTC;		// append RTC to page data on transmit
 					// for class 2.0:
     fxStr	class2PIECmd;		// cmd to set proc interrupt handling
@@ -159,6 +165,7 @@ public:
     fxStr	class2SACmd;		// cmd to set subaddress
     fxStr	class2PACmd;		// cmd to set selective polling address
     fxStr	class2PWCmd;		// cmd to set password for transmit/poll
+    bool	class2UseHex;		// parse capabilities strings as hex
 
     FlowControl	flowControl;		// DTE-DCE flow control method
     BaudRate	maxRate;		// max DTE-DCE rate to try
