@@ -1,4 +1,4 @@
-/*	$Id: ModemServer.h,v 1.2 1999/06/13 07:41:04 robert Exp $ */
+/*	$Id: ModemServer.h,v 1.4 2002/10/18 19:08:28 darren Exp $ */
 /*
  * Copyright (c) 1990-1996 Sam Leffler
  * Copyright (c) 1991-1996 Silicon Graphics, Inc.
@@ -134,6 +134,7 @@ protected:
     void	timerExpired(long, long);
     int		getModemLine(char buf[], u_int bufSize, long ms = 0);
     int		getModemChar(long ms = 0);
+    bool	isModemInput() const;
     void	flushModemInput();
     bool	putModem(const void* data, int n, long ms = 0);
     bool	putModem1(const void* data, int n, long ms = 0);
@@ -164,6 +165,7 @@ protected:
     void	traceModemOp(const char* fmt ...);
     void	traceStatus(int kind, const char* fmt ...);
 // modem locking interfaces implemented in derived class
+    virtual bool canLockModem() = 0;
     virtual bool lockModem() = 0;
     virtual void unlockModem() = 0;
 // notification interfaces implemented in derived class
@@ -215,4 +217,7 @@ inline const fxStr& ModemServer::getModemDeviceID() const
 inline const fxStr& ModemServer::getModemNumber() const
     { return FAXNumber; }
 inline const fxStr& ModemServer::getCommID() const	{ return commid; }
+inline bool ModemServer::isModemInput() const
+    { return rcvNext < rcvCC; }
+
 #endif /* _ModemServer_ */
