@@ -1,4 +1,4 @@
-/*	$Id: faxGettyApp.h,v 1.3 2001/07/02 06:39:05 darren Exp $ */
+/*	$Id: faxGettyApp.h,v 1.5 2002/10/18 19:08:29 darren Exp $ */
 /*
  * Copyright (c) 1990-1996 Sam Leffler
  * Copyright (c) 1991-1996 Silicon Graphics, Inc.
@@ -88,9 +88,9 @@ private:
 
     static faxGettyApp* _instance;
 
-    static const stringtag strings[];
-    static const numbertag numbers[];
-    static const booltag booleans[];
+    static stringtag strings[];
+    static numbertag numbers[];
+    static booltag booleans[];
 
     static const fxStr recvDir;
 
@@ -101,6 +101,7 @@ private:
     void	setAnswerRotary(const fxStr& value);
 // modem handling
     bool	isModemLocked();
+    bool	canLockModem();
     bool	lockModem();
     void	unlockModem();
     bool	setupModem();
