@@ -1,4 +1,4 @@
-/*	$Id: HylaFAXServer.h,v 1.4 1999/07/18 13:19:34 robert Exp $ */
+/*	$Id: HylaFAXServer.h,v 1.5 2002/06/15 18:00:09 darren Exp $ */
 /*
  * Copyright (c) 1995-1996 Sam Leffler
  * Copyright (c) 1995-1996 Silicon Graphics, Inc.
@@ -349,8 +349,8 @@ protected:
     /*
      * Configuration file support.
      */
-    static const stringtag strings[];
-    static const numbertag numbers[];
+    static stringtag strings[];
+    static numbertag numbers[];
 
     void resetConfig();
     void setupConfig();
