@@ -1,4 +1,4 @@
-/*	$Id: SendFaxJob.h,v 1.3 2001/08/12 23:40:36 darren Exp $ */
+/*	$Id: SendFaxJob.h,v 1.5 2002/06/15 18:00:12 darren Exp $ */
 /*
  * Copyright (c) 1993-1996 Sam Leffler
  * Copyright (c) 1993-1996 Silicon Graphics, Inc.
@@ -68,6 +68,7 @@ private:
     fxStr	jobid;			// job ID
     fxStr	groupid;		// job-group ID
     fxStr	jobtag;			// user-specified job identifier
+    fxStr	doneop;			// job doneop control
     FaxNotify	notify;			// job notification control
     fxStr	mailbox;		// mail address for notification
 
@@ -112,9 +113,9 @@ private:
     FaxPageChop	pagechop;		// page chop handling
     float	chopthreshold;		// white space threshold for chopping
 
-    static const SFJ_stringtag strings[];
-    static const SFJ_numbertag numbers[];
-    static const SFJ_floattag floats[];
+    static SFJ_stringtag strings[];
+    static SFJ_numbertag numbers[];
+    static SFJ_floattag floats[];
 
     int getSpeed(const char* value) const;
 public:
@@ -130,6 +131,8 @@ public:
     const fxStr& getJobID(void) const;
     const fxStr& getGroupID(void) const;
 
+    void setDoneOp(const char*);
+
     /*
      * Job notification.
      */
