@@ -1,4 +1,4 @@
-/*	$Id: faxmsg.c,v 1.4 2000/09/20 12:23:01 robert Exp $ */
+/*	$Id: faxmsg.c,v 1.5 2002/10/01 14:13:43 darren Exp $ */
 /*
  * Copyright (c) 1990-1996 Sam Leffler
  * Copyright (c) 1991-1996 Silicon Graphics, Inc.
@@ -93,6 +93,11 @@ main(int argc, char** argv)
 	usage = "[-q queue-dir] modem";
 	cmdfmt = "Z";
 	modemRequired = 1;
+    } else if (strcmp(appname, "faxlock") == 0) {
+	opts = "q:";
+	usage = "[-q queue-dir] modem";
+	cmdfmt = "L";
+	modemRequired = 1;
     } else {
 	fatal("Unrecognized command name %s", appname);
     }
